@@ -26,6 +26,7 @@
 #include "connection.h"
 #include "essid-list.h"
 #include "nm-integration.h"
+#include "callbacks.h"
 
 extern GstTool *tool;
 
@@ -138,6 +139,9 @@ connection_essids_combo_init (GtkComboBoxEntry *combo)
 
   /* reuse text cell renderer for the essid */
   gtk_combo_box_entry_set_text_column (combo, 1);
+
+  g_signal_connect (gtk_bin_get_child (GTK_BIN (combo)), "changed",
+		    G_CALLBACK (on_dialog_changed), tool);
 }
 
 static void
@@ -310,7 +314,7 @@ wireless_dialog_prepare (GstConnectionDialog *dialog)
 		NULL);
 
   connection_combo_set_value (GTK_COMBO_BOX (dialog->key_type_combo), key_type);
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dialog->essid)->child), (essid) ? essid : "");
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (dialog->essid))), (essid) ? essid : "");
   gtk_entry_set_text (GTK_ENTRY (dialog->wep_key), (key) ? key : "");
 
 #ifdef HAVE_LIBIW_H
@@ -333,13 +337,19 @@ wireless_dialog_save (GstConnectionDialog *dialog)
 
   key_type = connection_combo_get_value (GTK_COMBO_BOX (dialog->key_type_combo));
   g_object_set (G_OBJECT (dialog->iface),
-		"essid",   get_entry_text (GTK_BIN (dialog->essid)->child),
+		"essid",   get_entry_text (gtk_bin_get_child (GTK_BIN (dialog->essid))),
 		"key", get_entry_text (dialog->wep_key),
 		"key-type", key_type,
 		NULL);
   g_free (key_type);
 }
 
+static gboolean
+wireless_dialog_check_fields (GstConnectionDialog *dialog)
+{
+  return (get_entry_text (gtk_bin_get_child (GTK_BIN (dialog->essid))) != NULL);
+}
+
 static void
 plip_dialog_prepare (GstConnectionDialog *dialog)
 {
@@ -426,7 +436,7 @@ ppp_dialog_prepare (GstConnectionDialog *dialog)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->peerdns), peerdns);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->persist), persist);
 
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dialog->serial_port)->child),
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (dialog->serial_port))),
                       (serial_port) ? serial_port : "");
 
   gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->volume), volume);
@@ -469,7 +479,7 @@ ppp_dialog_save (GstConnectionDialog *dialog)
                 "default-gateway", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->default_gw)),
                 "use-peer-dns", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->peerdns)),
                 "persistent",   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->persist)),
-                "serial-port",  get_entry_text (GTK_BIN (dialog->serial_port)->child),
+                "serial-port",  get_entry_text (gtk_bin_get_child (GTK_BIN (dialog->serial_port))),
                 "volume",       gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->volume)),
                 "dial-type",    gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->dial_type)),
 		"apn",          get_entry_text (dialog->apn),
@@ -499,7 +509,7 @@ ppp_dialog_check_fields (GstConnectionDialog *dialog)
   if (strcmp (connection_type, "modem") == 0)
     valid = (get_entry_text (dialog->login) &&
 	     get_entry_text (dialog->phone_number) &&
-	     get_entry_text (GTK_BIN (dialog->serial_port)->child));
+	     get_entry_text (gtk_bin_get_child (GTK_BIN (dialog->serial_port))));
   else if (strcmp (connection_type, "isdn") == 0)
     valid = (get_entry_text (dialog->login) &&
 	     get_entry_text (dialog->phone_number));
@@ -508,7 +518,7 @@ ppp_dialog_check_fields (GstConnectionDialog *dialog)
 	     gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->pppoe_interface_combo)) != -1);
   else if (strcmp (connection_type, "gprs") == 0)
     valid = (get_entry_text (dialog->apn) &&
-	     get_entry_text (GTK_BIN (dialog->serial_port)->child));
+	     get_entry_text (gtk_bin_get_child (GTK_BIN (dialog->serial_port))));
 
   g_free (connection_type);
 
@@ -756,7 +766,7 @@ connection_dialog_prepare (GstConnectionDialog *dialog, OobsIface *iface)
   dialog->iface = g_object_ref (iface);
   active = oobs_iface_get_configured (dialog->iface);
 
-  title = g_strdup_printf (_("%s Properties\n"),
+  title = g_strdup_printf (_("%s Properties"),
 			   oobs_iface_get_device_name (dialog->iface));
   gtk_window_set_title (GTK_WINDOW (dialog->dialog), title);
   g_free (title);
@@ -792,8 +802,9 @@ connection_dialog_prepare (GstConnectionDialog *dialog, OobsIface *iface)
 void
 connection_save (GstConnectionDialog *dialog)
 {
-  gboolean active;
+  gboolean active, was_configured;
 
+  was_configured = oobs_iface_get_configured (dialog->iface);
   active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->connection_configured));
 
   if (OOBS_IS_IFACE_PPP (dialog->iface))
@@ -809,6 +820,16 @@ connection_save (GstConnectionDialog *dialog)
     plip_dialog_save (dialog);
 
   oobs_iface_set_configured (dialog->iface, active);
+
+  if (!was_configured)
+    oobs_iface_set_active (dialog->iface, TRUE);
+
+  /* sync auto and active, this may happen either because
+   * it was just set active, or the interface was already
+   * manually configured, but not marked as auto.
+   */
+  if (oobs_iface_get_active (dialog->iface))
+    oobs_iface_set_auto (dialog->iface, TRUE);
 }
 
 void
@@ -816,8 +837,10 @@ connection_check_fields (GstConnectionDialog *dialog)
 {
   gboolean active = FALSE;
 
-  if (OOBS_IS_IFACE_ETHERNET (dialog->iface) ||
-      OOBS_IS_IFACE_WIRELESS (dialog->iface) ||
+  if (OOBS_IS_IFACE_WIRELESS (dialog->iface))
+    active = (ethernet_dialog_check_fields (dialog) &&
+	      wireless_dialog_check_fields (dialog));
+  else if (OOBS_IS_IFACE_ETHERNET (dialog->iface) ||
       OOBS_IS_IFACE_IRLAN    (dialog->iface))
     active = ethernet_dialog_check_fields (dialog);
   else if (OOBS_IS_IFACE_PLIP (dialog->iface))
